DOcplex, IBM Decision Optimization Modeling for Python
======================================================

Welcome to the IBM Decision Optimization CPLEX Modeling for Python.
Licensed under the Apache License v2.0.

With this library, you can quickly and easily add the power of optimization to
your application. You can model your problems by using the Python API and solve
them on the cloud with the IBM Decision Optimization on Cloud service or on
your computer with IBM ILOG CPLEX Optimization Studio.

This library is composed of 2 modules:

    * IBM Decision Optimization CPLEX Optimizer Modeling for Python - with namespace docplex.mp
    * IBM Decision Optimization CP Optimizer Modeling for Python - with namespace docplex.cp

Solving with CPLEX locally requires that IBM ILOG CPLEX Optimization Studio V12.8 or later
is installed on your machine.

Solving with the IBM Decision Optimization on Cloud service requires that you
register for an account and get the API key.

This library is `numpy` friendly.

`Documentation <https://github.com/IBMDecisionOptimization/docplex-doc>`_

`Examples <https://github.com/IBMDecisionOptimization/docplex-examples>`_

Installation
------------

*  ``pip install docplex``

